<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>CollectionSetupModel</name>
    <message>
        <location filename="../src/collectionsetupmodel.cpp" line="97"/>
        <source>Select folders for music collection</source>
        <translation>Sélectionner les dossiers de votre bibliothèque de musique</translation>
    </message>
</context>
<context>
    <name>CollectionTree</name>
    <message>
        <location filename="../src/collectiontree.cpp" line="56"/>
        <location filename="../src/collectiontree.cpp" line="128"/>
        <location filename="../src/collectiontree.cpp" line="358"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="106"/>
        <location filename="../src/collectiontree.cpp" line="360"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="117"/>
        <location filename="../src/collectiontree.cpp" line="361"/>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="321"/>
        <source>Add to PlayList&amp;1</source>
        <translation>Ajouter à la liste de lecture&amp;1</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="323"/>
        <source>Add to PlayList&amp;2</source>
        <translation>Ajouter à la liste de lecture&amp;2</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="326"/>
        <source>Re-scan collection</source>
        <translation>Réanalyser la bibliothèque</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="357"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="359"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="362"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <location filename="../src/collectiontree.cpp" line="365"/>
        <source>Meta Information</source>
        <translation>Méta Information</translation>
    </message>
</context>
<context>
    <name>CollectionTreeItem</name>
    <message>
        <location filename="../src/collectiontreeitem.cpp" line="97"/>
        <source>All</source>
        <translation>Tous</translation>
    </message>
</context>
<context>
    <name>CollectionWidget</name>
    <message>
        <location filename="../src/collectionwidget.cpp" line="61"/>
        <source>Random Tracks</source>
        <translation>Pistes aléatoires</translation>
    </message>
    <message>
        <location filename="../src/collectionwidget.cpp" line="64"/>
        <source>Enter space-separated terms to filter collection</source>
        <translation>Entrer des termes séparés par des espaces pour filtrer la bibliothèque</translation>
    </message>
</context>
<context>
    <name>Core::Internal::FancyTabWidget</name>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="646"/>
        <source>Large sidebar</source>
        <translation>Grande barre latérale</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="647"/>
        <source>Small sidebar</source>
        <translation>Petite barre latérale</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="648"/>
        <source>Plain sidebar</source>
        <translation>Barre latérale</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="649"/>
        <source>Tabs on top</source>
        <translation>Onglets du haut</translation>
    </message>
    <message>
        <location filename="../src/fancytabwidget.cpp" line="650"/>
        <source>Icons on top</source>
        <translation>Icônes du haut</translation>
    </message>
</context>
<context>
    <name>DjBrowser</name>
    <message>
        <location filename="../src/djbrowser.cpp" line="69"/>
        <source>Add a new AutoDj</source>
        <translation>Ajouter un nouveau AutoDj</translation>
    </message>
    <message>
        <location filename="../src/djbrowser.cpp" line="80"/>
        <source>Add a new record case for current AutoDj</source>
        <translation>Ajouter un nouvel enregistrement à l&apos;AutoDJ courant</translation>
    </message>
</context>
<context>
    <name>DjFilterWidget</name>
    <message>
        <location filename="../src/djfilterwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="214"/>
        <source>Record Case</source>
        <translation>Enregistrement</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="320"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;count of records which fit to this filter(s)&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;nombre d&apos;enregistrements qui correspondent à ce(s) filtre(s)&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="331"/>
        <location filename="../src/djfilterwidget.ui" line="388"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="354"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="452"/>
        <source>how many records per turn</source>
        <translation>combien d&apos;enregistrements par tour</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1142"/>
        <source>Activate this record case</source>
        <translation>Activer cet enregistrement</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1145"/>
        <source>set</source>
        <translation>set</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1148"/>
        <source>Alt+J</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1172"/>
        <source>Count</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1192"/>
        <source>Remove this record case</source>
        <translation>Supprimer cet enregistrement</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1195"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="1685"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#e1e1e1;&quot;&gt;Path&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#e1e1e1;&quot;&gt;Emplacement&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2167"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2617"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2664"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirmer la suppression&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.ui" line="2676"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../src/djfilterwidget.cpp" line="157"/>
        <location filename="../src/djfilterwidget.cpp" line="203"/>
        <source>of</source>
        <translation>sur</translation>
    </message>
</context>
<context>
    <name>DjSettings</name>
    <message>
        <location filename="../src/djsettings.ui" line="26"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../src/djsettings.ui" line="47"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
<context>
    <name>DjWidget</name>
    <message>
        <location filename="../src/djwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="100"/>
        <source>AutoDJ</source>
        <translation>AutoDj</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="137"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Main&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;DJ Principal&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="208"/>
        <source>Start a session of this DJ</source>
        <translation>Démarrer une session pour ce DJ</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="222"/>
        <source>Remove this DJ</source>
        <translation>Supprimer ce DJ</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="225"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="253"/>
        <source>TextLabel</source>
        <translation>Texte de l&apos;étiquette</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="281"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirmer la suppression&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/djwidget.ui" line="290"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="135"/>
        <source>This Dj plays: </source>
        <translation>Ce Dj joue: </translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="136"/>
        <source>cases</source>
        <translation>événements</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="136"/>
        <source>case</source>
        <translation>événement</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="139"/>
        <source>tracks</source>
        <translation>pistes</translation>
    </message>
    <message>
        <location filename="../src/djwidget.cpp" line="140"/>
        <source>hours</source>
        <translation>heures</translation>
    </message>
</context>
<context>
    <name>Knowthelist</name>
    <message>
        <location filename="../src/knowthelist.ui" line="14"/>
        <source>Knowthelist</source>
        <translation>Knowthelist</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1141"/>
        <source>Fader</source>
        <translation>Fondu</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1836"/>
        <source>AutoD&amp;J</source>
        <translation>AutoD&amp;J</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="1839"/>
        <location filename="../src/knowthelist.ui" line="5724"/>
        <source>Alt+J</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="2499"/>
        <source>Set</source>
        <translation>Set</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="4845"/>
        <source>FadeNo&amp;w</source>
        <translation>Fondr&amp;e (Fader)</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="4848"/>
        <source>Alt+W</source>
        <translation>Alt+W</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5096"/>
        <location filename="../src/knowthelist.ui" line="5777"/>
        <source>Gain</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5721"/>
        <source>AGC</source>
        <translation>AGC</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5798"/>
        <location filename="../src/knowthelist.ui" line="5822"/>
        <source>Low</source>
        <translation>Graves</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5843"/>
        <location filename="../src/knowthelist.ui" line="5867"/>
        <source>Mid</source>
        <translation>Médiums</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="5891"/>
        <location filename="../src/knowthelist.ui" line="5915"/>
        <source>High</source>
        <translation>Aigus</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="6890"/>
        <source>0:00.0</source>
        <translation>0:00.0</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7192"/>
        <source>-0:00.0</source>
        <translation>-0:00.0</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7559"/>
        <source>MonitorPlayer</source>
        <translation>Lecteur Audio</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7615"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;settings&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#df0000;&quot;&gt;No 2nd soundcard selected!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;settings&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#df0000;&quot;&gt;Pas de seconde carte son sélectionnée!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.ui" line="7640"/>
        <source>Settings</source>
        <translation>Réglages</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="188"/>
        <source>Collection</source>
        <translation>Bibliothèque</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="252"/>
        <source>AutoDJ</source>
        <translation>AutoDJ</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="260"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../src/knowthelist.cpp" line="285"/>
        <source>Lists</source>
        <translation>Listes</translation>
    </message>
</context>
<context>
    <name>ModeSelector</name>
    <message>
        <location filename="../src/modeselector.ui" line="31"/>
        <source>Frame</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="70"/>
        <source>View: Artist &gt; Album</source>
        <translation>Vue: Artiste &gt; Album</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="101"/>
        <source>View: Year &gt; Artist &gt; Album</source>
        <translation>Vue: Année &gt; Artiste Album</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="104"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="132"/>
        <source>View: Genre &gt; Artist &gt; Album</source>
        <translation>Vue: Genre &gt; Artiste &gt; Album</translation>
    </message>
    <message>
        <location filename="../src/modeselector.ui" line="135"/>
        <source>G</source>
        <translation>G</translation>
    </message>
</context>
<context>
    <name>PlayerWidget</name>
    <message>
        <location filename="../src/playerwidget.ui" line="20"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="754"/>
        <source>texttexttextt</source>
        <translation>textetextetexte</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="855"/>
        <source>TextLabel</source>
        <translation>Texte de l&apos;étiquette</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="1351"/>
        <source>00:00</source>
        <translation>00:00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="1809"/>
        <location filename="../src/playerwidget.ui" line="2758"/>
        <source>.00</source>
        <translation>.00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2294"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Time remain&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Durée restante&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2300"/>
        <source>-00:00</source>
        <translation>-00:00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2789"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Seconds of silence at the end &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; color:#ffffff;&quot;&gt;Secondes de silence à la fin&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="2795"/>
        <source>-00</source>
        <translation>-00</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="3048"/>
        <source>Jump to the point where the music starts mainly</source>
        <translation>Sauter le blanc du début de la musique</translation>
    </message>
    <message>
        <source>Jump to start position</source>
        <translation>Aller à la position de départ</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.ui" line="3034"/>
        <source>Cue</source>
        <translation>CUE</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="127"/>
        <source>Tracks</source>
        <translation>Pistes</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="127"/>
        <source>Track</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="132"/>
        <source>Hours</source>
        <translation>Heures</translation>
    </message>
    <message>
        <location filename="../src/playerwidget.cpp" line="354"/>
        <source>No track</source>
        <translation>Aucune piste</translation>
    </message>
</context>
<context>
    <name>Playlist</name>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>No</source>
        <translation>N°</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <source>Played</source>
        <translation>Joué</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <location filename="../src/playlist.cpp" line="1043"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="71"/>
        <location filename="../src/playlist.cpp" line="1042"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1044"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1046"/>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <location filename="../src/playlist.cpp" line="1045"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="72"/>
        <source>Track</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="73"/>
        <source>Length</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="73"/>
        <source>Rate</source>
        <translation>Note</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="973"/>
        <source>Add to PlayList&amp;1</source>
        <translation>Ajouter à la liste de lecture&amp;1</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="975"/>
        <source>Add to PlayList&amp;2</source>
        <translation>Ajouter à la liste de lecture&amp;2</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="979"/>
        <source>&amp;Load</source>
        <translation>&amp;Charger</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="982"/>
        <source>Load as &amp;Next</source>
        <translation>Chargement &amp;Suivant</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="985"/>
        <source>&amp;Prelisten Track</source>
        <translation>&amp;Pré-écouter la piste</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="988"/>
        <source>&amp;Search for: &apos;%1&apos;</source>
        <translation>&amp;Rechercher:&apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="992"/>
        <source>&amp;Remove Selected</source>
        <translation>&amp;Supprimer la sélection</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="994"/>
        <source>&amp;Open File Location</source>
        <translation>&amp;Ouvrir l&apos;emplacement du fichier</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="996"/>
        <source>&amp;View Tag Information</source>
        <translation>&amp;Afficher les informations du Tag</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="1047"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <location filename="../src/playlist.cpp" line="1050"/>
        <source>Meta Information</source>
        <translation>Méta information</translation>
    </message>
</context>
<context>
    <name>PlaylistBrowser</name>
    <message>
        <source>Save loaded player lists into a file</source>
        <translation type="obsolete">Sauvegarder dans un fichier les listes de lecture chargées</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="59"/>
        <source>Add a new list and store current tracks</source>
        <translation>Ajouter une nouvelle liste et stocker les pistes en cours</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="118"/>
        <source>Top Tracks</source>
        <translation>Top titres</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="120"/>
        <source>Most played tracks</source>
        <translation>Titres les plus joués</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="133"/>
        <source>Last Tracks</source>
        <translation>Derniers titres</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="135"/>
        <source>Recently played tracks</source>
        <translation>Titres récemment joués</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="148"/>
        <source>Favorites Tracks</source>
        <translation>Titres favoris</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="150"/>
        <source>High rated tracks</source>
        <translation>Titres les mieux notés</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="174"/>
        <source>tracks</source>
        <translation>pistes</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="175"/>
        <source>hours</source>
        <translation>heures</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="313"/>
        <source>Save Play List</source>
        <translation>Sauvegarder la liste de lecture</translation>
    </message>
    <message>
        <location filename="../src/playlistbrowser.cpp" line="314"/>
        <source>Enter a name for the new list</source>
        <translation>Entrer un nom pour la nouvelle liste</translation>
    </message>
    <message>
        <source>Playlists (*.xspf);;All Files (*)</source>
        <translation type="obsolete">Listes de lecture (*.xspf);;Tous les fichiers (*)</translation>
    </message>
</context>
<context>
    <name>PlaylistWidget</name>
    <message>
        <location filename="../src/playlistwidget.ui" line="14"/>
        <source>Frame</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="111"/>
        <source>Click here to show the content of this list</source>
        <translation>Cliquez ici pour afficher le contenu de cette liste</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="114"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;charts&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;Most Played&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;charts&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#d0fff8;&quot;&gt;Les plus jouées&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="137"/>
        <source>TextLabel</source>
        <translation>Texte de l&apos;étiquette</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="209"/>
        <source>Load all tracks of this list directly into player playlists</source>
        <translation>Charger tous les titres directement dans les listes de lecture</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="236"/>
        <source>Remove this list</source>
        <translation>Supprimer cette liste</translation>
    </message>
    <message>
        <source>Remove this playlist</source>
        <translation type="obsolete">Supprimer cette liste de lecture</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="239"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirm the remove&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Confirmer la suppression&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/playlistwidget.ui" line="273"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="65"/>
        <location filename="../src/main.cpp" line="68"/>
        <source>Unable to load database</source>
        <translation>Impossible de charger la base de données</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="66"/>
        <source>This application needs the QT5 SQLITE driver (libqt5-sql-sqlite)</source>
        <translation>Cette application requiert le pilote QT5 SQLite (qt5-database-plugin-sqlite)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="69"/>
        <source>This application needs the QT4 SQLITE driver (libqt4-sql-sqlite)</source>
        <translation>Cette application requiert le pilote QT4 SQLite (qt4-database-plugin-sqlite)</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="52"/>
        <location filename="../src/playlistitem.cpp" line="53"/>
        <location filename="../src/playlistitem.cpp" line="80"/>
        <location filename="../src/playlistitem.cpp" line="122"/>
        <location filename="../src/playlistitem.cpp" line="135"/>
        <location filename="../src/track.cpp" line="134"/>
        <location filename="../src/track.cpp" line="135"/>
        <location filename="../src/track.cpp" line="136"/>
        <location filename="../src/track.cpp" line="138"/>
        <location filename="../src/track.cpp" line="146"/>
        <location filename="../src/track.cpp" line="244"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="65"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="66"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="67"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="68"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="69"/>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <location filename="../src/playlistitem.cpp" line="70"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.ui" line="20"/>
        <source>Settings</source>
        <translation>Réglages</translation>
    </message>
    <message>
        <source>New Row</source>
        <translation type="obsolete">Nouvelle Ligne</translation>
    </message>
    <message>
        <source>Neue Zeile</source>
        <translation type="obsolete">Nouvelle Ligne</translation>
    </message>
    <message>
        <source>New Column</source>
        <translation type="obsolete">Nouvelle Colonne</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="141"/>
        <source>Fader</source>
        <translation>Fondu (Fader)</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="146"/>
        <source>Collection</source>
        <translation>Bibliothèque</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="151"/>
        <source>Audio devices</source>
        <translation>Périphériques Audio</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="156"/>
        <source>AutoDJ</source>
        <translation>AutoDJ</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="161"/>
        <source>Playlists</source>
        <translation>Listes de lecture</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="166"/>
        <source>File browser</source>
        <translation>Explorateur de fichiers</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="171"/>
        <source>Common</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="198"/>
        <source>Fader settings</source>
        <translation>Réglages du fondu (Fader)</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="236"/>
        <source>Start fading before song end</source>
        <translation>Commencer le fondu avant la fin du morceau</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="265"/>
        <location filename="../src/settingsdialog.ui" line="291"/>
        <source>12s</source>
        <translation>12s</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="278"/>
        <source>Fader Time</source>
        <translation>Durée du fondu</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="326"/>
        <source>Skip silent at start (AutoCue)</source>
        <translation>Supprimer le silence au démarrage (AutoCue)</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="342"/>
        <source>Skip silent at the end</source>
        <translation>supprimer le silence à la fin</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="374"/>
        <source>Scan for new files and update the music collection</source>
        <translation>Analyser les nouveaux fichiers et mettre à jour la bibliothèque de musique</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="377"/>
        <source>Watch folders for changes</source>
        <translation>Surveiller les changements des dossiers</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="399"/>
        <source>Scan Now</source>
        <translation>Analyser</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="406"/>
        <source>Scan folders for songs</source>
        <translation>Analyser les dossiers pour les chansons</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="413"/>
        <source>Play Counter Statistics</source>
        <translation>Statistiques du nombre de lectures</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="420"/>
        <source>Reset</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="442"/>
        <source>Monitor Player</source>
        <translation>Carte(s) Son</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="465"/>
        <source>Device Settings</source>
        <translation>Réglages des périphériques</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="496"/>
        <source>AutoDJ settings</source>
        <translation>Réglages de l&apos;AutoDJ</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="538"/>
        <source>Minimum tracks within each playlist </source>
        <translation>Nombre minimum de pistes dans chaque liste de lecture</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="564"/>
        <source>DJ Count</source>
        <translation>Nombre de DJs</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="596"/>
        <source>DJ Names</source>
        <translation>Noms des DJs</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="609"/>
        <source>Filter Count</source>
        <translation>Nombre de filtres</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="622"/>
        <source>Increment play counter for AutoDj selected tracks</source>
        <translation>Incrémenter le compteur de lecture pour les pistes AutoDj sélectionnées</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="653"/>
        <source>Auto Remove Played Tracks</source>
        <translation>Supprimer automatiquement les pistes jouées</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="666"/>
        <source>Playlist Settings</source>
        <translation>Réglages des listes de lecture</translation>
    </message>
    <message>
        <source>Playlist Folder</source>
        <translation type="obsolete">Dossier de la liste de lecture</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="704"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="691"/>
        <source>Browser Root</source>
        <translation>Navigateur</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="717"/>
        <source>File Browser Settings</source>
        <translation>Réglages des explorateurs de fichiers</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="794"/>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="807"/>
        <source>Common Settings</source>
        <translation>Réglages Général</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="841"/>
        <source>Change the language of the application (needs restart)</source>
        <translation>Changer la langue de l&apos;application (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.ui" line="867"/>
        <source>About</source>
        <translation>À Propos</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="276"/>
        <source>About Knowthelist</source>
        <translation>À Propos de Knowthelist</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Knowthelist&lt;/h3&gt;&lt;br /&gt;Copyright (C) 2005-2014 Mario Stephan &lt;br /&gt;&lt;a href=&apos;mailto:mstephan@shared-files.de&apos;&gt;mstephan@shared-files.de&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;&lt;a href=&apos;http://knowthelist.github.io/knowthelist&apos;&gt;http://knowthelist.github.io/knowthelist&lt;/a&gt;</source>
        <translation type="obsolete">&lt;h3&gt;Knowthelist&lt;/h3&gt;&lt;br /&gt;Copyright (C) 2005-2014 Mario Stephan &lt;br /&gt;&lt;a href=&apos;mailto:mstephan@shared-files.de&apos;&gt;mstephan@shared-files.de&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;&lt;a href=&apos;http://knowthelist.github.io/knowthelist&apos;&gt;http://knowthelist.github.io/knowthelist&lt;/a&gt;</translation>
    </message>
</context>
</TS>
